==> notolog-1.0.2-py3-none-any.whl: notolog/lexemes/tr/toolbar.py <==
# Turkish lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Yeni belge",
    "actions_accessible_name_new_document": "Yeni belge",
    "actions_label_open": "Aç",
    "actions_accessible_name_open": "Belge aç",
    "actions_label_save": "Kaydet",
    "actions_accessible_name_save": "Belgeyi kaydet",
    "actions_label_save_as": "Farklı Kaydet",
    "actions_accessible_name_save_as": "Belgeyi farklı kaydet",
    "actions_label_sync": "Senkronize Et",
    "actions_accessible_name_sync": "Belgeyi dış depolama ile senkronize et",
    "actions_label_edit": "Düzenle",
    "actions_accessible_name_edit": "Dosyayı düzenle",
    "actions_label_source": "Kaynak",
    "actions_accessible_name_source": "Kaynak kodu",
    "actions_label_encrypt": "Şifrele",
    "actions_accessible_name_encrypt": "Dosyayı şifrele",
    "actions_label_decrypt": "Şifreyi Çöz",
    "actions_accessible_name_decrypt": "Dosyanın şifresini çöz",
    "actions_label_bold": "Kalın",
    "actions_accessible_name_bold": "Kalın metin formatı",
    "actions_label_italic": "İtalik",
    "actions_accessible_name_italic": "İtalik metin formatı",
    "actions_label_underline": "Altı Çizili",
    "actions_accessible_name_underline": "Altı çizili metin formatı",
    "actions_label_strikethrough": "Üstü Çizili",
    "actions_accessible_name_strikethrough": "Üstü çizili metin formatı",
    "actions_label_blockquote": "Alıntı",
    "actions_accessible_name_blockquote": "Alıntı metin formatı",
    "actions_label_color_picker": "Renk Seçici",
    "actions_accessible_name_color_picker": "Metin rengi seç",
    "actions_label_ai_assistant": "Yapay Zeka Asistanı",
    "actions_accessible_name_ai_assistant": "Yapay Zeka Asistanını başlat",
    "actions_label_about": "Hakkında",
    "actions_accessible_name_about": "Uygulama hakkında",
    "actions_label_exit": "Çıkış",
    "actions_accessible_name_exit": "Uygulamadan çık",
    "actions_label_settings": "Ayarlar",
    "actions_accessible_name_settings": "Uygulama ayarları",

    "search_input_label": "Arama",
    "search_input_placeholder_text": "belgedeki metin",
    "search_input_accessible_description": "Arama giriş alanı",
    "search_buttons_label_clear": "Aramayı temizle",
    "search_buttons_accessible_name_clear": "Arama giriş alanını temizle",
    "search_buttons_label_prev": "Önceki arama",
    "search_buttons_accessible_name_prev": "Önceki arama sonucu",
    "search_buttons_label_next": "Sonraki arama",
    "search_buttons_accessible_name_next": "Sonraki arama sonucu",
    "search_case_sensitive_label": "Büyük/küçük harfe duyarlı",
    "search_case_sensitive_tooltip": "Büyük/küçük harfe duyarlı arama",
}

==> notolog-1.0.7-py3-none-any.whl: notolog/lexemes/tr/toolbar.py <==
# Turkish lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Yeni belge",
    "actions_accessible_name_new_document": "Yeni belge",
    "actions_label_open": "Aç",
    "actions_accessible_name_open": "Belge aç",
    "actions_label_save": "Kaydet",
    "actions_accessible_name_save": "Belgeyi kaydet",
    "actions_label_save_as": "Farklı Kaydet",
    "actions_accessible_name_save_as": "Belgeyi farklı kaydet",
    "actions_label_sync": "Senkronize Et",
    "actions_accessible_name_sync": "Belgeyi dış depolama ile senkronize et",
    "actions_label_edit": "Düzenle",
    "actions_accessible_name_edit": "Dosyayı düzenle",
    "actions_label_source": "Kaynak",
    "actions_accessible_name_source": "Kaynak kodu",
    "actions_label_encrypt": "Şifrele",
    "actions_accessible_name_encrypt": "Dosyayı şifrele",
    "actions_label_decrypt": "Şifreyi Çöz",
    "actions_accessible_name_decrypt": "Dosyanın şifresini çöz",
    "actions_label_bold": "Kalın",
    "actions_accessible_name_bold": "Kalın metin formatı",
    "actions_label_italic": "İtalik",
    "actions_accessible_name_italic": "İtalik metin formatı",
    "actions_label_underline": "Altı Çizili",
    "actions_accessible_name_underline": "Altı çizili metin formatı",
    "actions_label_strikethrough": "Üstü Çizili",
    "actions_accessible_name_strikethrough": "Üstü çizili metin formatı",
    "actions_label_blockquote": "Alıntı",
    "actions_accessible_name_blockquote": "Alıntı metin formatı",
    "actions_label_color_picker": "Renk Seçici",
    "actions_accessible_name_color_picker": "Metin rengi seç",
    "actions_label_ai_assistant": "Yapay Zeka Asistanı",
    "actions_accessible_name_ai_assistant": "Yapay Zeka Asistanını başlat",
    "actions_label_about": "Hakkında",
    "actions_accessible_name_about": "Uygulama hakkında",
    "actions_label_exit": "Çıkış",
    "actions_accessible_name_exit": "Uygulamadan çık",
    "actions_label_settings": "Ayarlar",
    "actions_accessible_name_settings": "Uygulama ayarları",

    "search_input_label": "Arama",
    "search_input_placeholder_text": "Belgede metin ara",
    "search_input_accessible_description": "Arama giriş alanı",
    "search_buttons_label_clear": "Aramayı temizle",
    "search_buttons_accessible_name_clear": "Arama giriş alanını temizle",
    "search_buttons_label_prev": "Önceki arama",
    "search_buttons_accessible_name_prev": "Önceki arama sonucu",
    "search_buttons_label_next": "Sonraki arama",
    "search_buttons_accessible_name_next": "Sonraki arama sonucu",
    "search_case_sensitive_accessible_name": "Büyük/küçük harfe duyarlı",
    "search_case_sensitive_tooltip": "Büyük/küçük harfe duyarlı arama",
}
